==> interactik-collaboratif-calendar-4.6.8-sources.jar: fr/toutatice/services/calendar/common/InteractikCalendarConstant.java <==
package fr.toutatice.services.calendar.common;

public final class InteractikCalendarConstant {

    /** Department */
	public static final String DEPARTEMENT_PROPERTY = "ttctik:departement";
	/** Date fin inscription */
	public static final String VILLE_PROPERTY = "ttctik:ville";
	/** Date debut inscription */
	public static final String DATE_DEBUT_INSCRIPTION_PROPERTY = "ttctik:datedebutinscription";
	/** Date fin inscription */
	public static final String DATE_FIN_INSCRIPTION_PROPERTY = "ttctik:datefininscription";
    /** URL inscription */
	public static final String URL_INSCRIPTION_PROPERTY = "ttctik:urlInscription";
	/** URL inscription */
	public static final String IMPORTED_PROPERTY = "ttctik:imported";
	
	public static final String LOCATION = "vevent:location";
	/** Agenda interactik */
	public static final String AGENDA_INTERACTIK = "AgendaInteractik";
	
    public static final String COOPERATIVE_VOCABULARY = "cooperative";
    
    public static final String COOPERATIVE_22 = "cooperativeCA";
    
    public static final String COOPERATIVE_29 = "cooperativeFI";
    
    public static final String COOPERATIVE_35 = "cooperativeIV";
    
    public static final String COOPERATIVE_56 = "cooperativeMO";
    
    public static final String COOPERATIVE_ACADEMIE = "cooperativeAcademie";
    
    public static final String INTERACTIK = "interactik";
    
    public static final String COOP_22 = "coopCA";
    
    public static final String COOP_29 = "coopFI";
    
    public static final String COOP_35 = "coopIV";
    
    public static final String COOP_56 = "coopMO";
    
    public static final String COOP_ACADEMIE = "coopAcademie";
    
    public static final String IS_INTERACTIK = "isInteractik";
    
    public static final String CODE_DEPARTEMENT_ACADEMIE = "aca";
    
    public static final String DOCUMENT_TYPE_EVENT_INTERACTIK = "VEVENTInteractik";
    
    public static final String DOCUMENT_TYPE_EVENT = "VEVENT";
}

==> interactik-collaboratif-calendar-4.7.4-sources.jar: fr/toutatice/services/calendar/common/InteractikCalendarConstant.java <==
package fr.toutatice.services.calendar.common;

public final class InteractikCalendarConstant {

    /** Department */
	public static final String DEPARTEMENT_PROPERTY = "ttctik:departement";
	/** Date fin inscription */
	public static final String VILLE_PROPERTY = "ttctik:ville";
	/** Date debut inscription */
	public static final String DATE_DEBUT_INSCRIPTION_PROPERTY = "ttctik:datedebutinscription";
	/** Date fin inscription */
	public static final String DATE_FIN_INSCRIPTION_PROPERTY = "ttctik:datefininscription";
    /** URL inscription */
	public static final String URL_INSCRIPTION_PROPERTY = "ttctik:urlInscription";
	/** URL inscription */
	public static final String IMPORTED_PROPERTY = "ttctik:imported";
	
	public static final String LOCATION = "vevent:location";
	/** Agenda interactik */
	public static final String AGENDA_INTERACTIK = "AgendaInteractik";
	
    public static final String COOPERATIVE_VOCABULARY = "cooperative";
    
    public static final String COOPERATIVE_22 = "cooperativeCA";
    
    public static final String COOPERATIVE_29 = "cooperativeFI";
    
    public static final String COOPERATIVE_35 = "cooperativeIV";
    
    public static final String COOPERATIVE_56 = "cooperativeMO";
    
    public static final String COOPERATIVE_ACADEMIE = "cooperativeAcademie";
    
    public static final String INTERACTIK = "interactik";
    
    public static final String COOP_22 = "coopCA";
    
    public static final String COOP_29 = "coopFI";
    
    public static final String COOP_35 = "coopIV";
    
    public static final String COOP_56 = "coopMO";
    
    public static final String COOP_ACADEMIE = "coopAcademie";
    
    public static final String IS_INTERACTIK = "isInteractik";
    
    public static final String CODE_DEPARTEMENT_ACADEMIE = "aca";
    
    public static final String DOCUMENT_TYPE_EVENT_INTERACTIK = "VEVENTInteractik";

    /** Organisateurs Nuxeo document property. */
    public static final String ORGANISATEURS_PROPERTY = "ttctik:organisateurs";
    /** Pôles disciplinaires Nuxeo document property. */
    public static final String POLES_DISCIPLINAIRES_PROPERTY = "ttctik:polesDisciplinaires";
    /** Thèmes Nuxeo document property. */
    public static final String THEMES_PROPERTY = "ttctik:themes";
    /** Niveaux Nuxeo document property. */
    public static final String NIVEAUX_PROPERTY = "ttctik:niveaux";
    /** Contenus Nuxeo document property. */
    public static final String CONTENUS_PROPERTY = "ttctik:contenus";
    /** Repères DNE Nuxeo document property. */
    public static final String REPERES_DNE_PROPERTY = "ttctik:reperesDne";
    
}
